.. _spider_dietiwag.org:

dietiwag.org
------------
Latest articles of `dietiwag.org <http://www.dietiwag.org>`_.

Configuration
~~~~~~~~~~~~~
Add ``dietiwag.org`` to the list of spiders:

.. code-block:: ini

   # List of spiders to run by default, one per line.
   spiders =
     dietiwag.org

